"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const context_1 = require("../styles/context");
module.exports = {
    meta: {
        docs: {
            description: "Enforce the `<style>` tags to has the `scoped` attribute.",
            category: "recommended",
            default: "warn",
            url: "https://future-architect.github.io/eslint-plugin-vue-scoped-css/rules/require-scoped.html",
            suggestion: true,
        },
        fixable: null,
        messages: {
            missing: "Missing `scoped` attribute.",
            add: "Add `scoped` attribute.",
        },
        schema: [],
        type: "suggestion",
    },
    create(context) {
        var _a, _b;
        const styles = context_1.getStyleContexts(context).filter(context_1.StyleContext.isValid);
        if (!styles.length) {
            return {};
        }
        const reporter = context_1.getCommentDirectivesReporter(context);
        const tokenStore = (_b = (_a = context.parserServices).getTemplateBodyTokenStore) === null || _b === void 0 ? void 0 : _b.call(_a);
        function report(node) {
            reporter.report({
                node: node.startTag,
                messageId: "missing",
                data: {},
                suggest: [
                    {
                        messageId: "add",
                        fix(fixer) {
                            const close = tokenStore.getLastToken(node.startTag);
                            return fixer.insertTextBefore(close, " scoped");
                        },
                    },
                ],
            });
        }
        return {
            "Program:exit"() {
                for (const style of styles) {
                    if (!style.scoped) {
                        report(style.styleElement);
                    }
                }
            },
        };
    },
};
