"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function isRootElement(element) {
    return element.type === "VElement" && isRootTemplate(element.parent);
}
exports.isRootElement = isRootElement;
function isRootTemplate(element) {
    return (element.type === "VElement" &&
        element.name === "template" &&
        element.parent.type === "VDocumentFragment");
}
function isTransitionElement(element) {
    return (element.type === "VElement" &&
        (element.name === "transition" || element.rawName === "Transition"));
}
exports.isTransitionElement = isTransitionElement;
function isTransitionGroupElement(element) {
    return (element.type === "VElement" &&
        (element.name === "transition-group" ||
            element.rawName === "TransitionGroup"));
}
function isSkipElement(element) {
    return (element.type === "VElement" &&
        (element.name === "template" || isTransitionElement(element)));
}
exports.isSkipElement = isSkipElement;
function isSlotElement(element) {
    return element.type === "VElement" && element.name === "slot";
}
exports.isSlotElement = isSlotElement;
function getWrapperTransition(element) {
    let parent = element.parent;
    while (parent.type === "VElement") {
        if (isTransitionElement(parent) || isTransitionGroupElement(parent)) {
            return parent;
        }
        if (!isSlotElement(parent) && !isSkipElement(parent)) {
            return null;
        }
        parent = parent.parent;
    }
    return null;
}
exports.getWrapperTransition = getWrapperTransition;
function isElementWrappedInTransition(element) {
    return Boolean(getWrapperTransition(element));
}
exports.isElementWrappedInTransition = isElementWrappedInTransition;
function getParentElement(element) {
    var _a;
    if (isRootElement(element)) {
        return null;
    }
    let parent = element.parent;
    while (parent && (isSkipElement(parent) || isSlotElement(parent))) {
        if (isRootElement(parent)) {
            return null;
        }
        parent = parent.parent;
    }
    return ((_a = parent) === null || _a === void 0 ? void 0 : _a.type) === "VElement" ? parent : null;
}
exports.getParentElement = getParentElement;
